@@ -1,3 +1,9 @@
+#' Maps file types to the reader functions used to autoload them.
+#'
+#' This list stores a mapping from regular expressions that match file
+#' extensions for the file types supported by ProjectTemplate to the
+#' reader functions that implement autoloading for those formats. Any
+#' new file type must be appended to this dispatch table.
 extensions.dispatch.table <- list("\\.csv$" = ProjectTemplate:::csv.reader,
                                   "\\.csv.bz2$" = ProjectTemplate:::csv.reader,
                                   "\\.csv.zip$" = ProjectTemplate:::csv.reader,
@@ -38,4 +44,6 @@ extensions.dispatch.table <- list("\\.csv$" = ProjectTemplate:::csv.reader,
                                   "\\.sas$" = ProjectTemplate:::xport.reader,
                                   "\\.xport$" = ProjectTemplate:::xport.reader,
                                   "\\.db$" = ProjectTemplate:::db.reader,
-                                  "\\.file$" = ProjectTemplate:::file.reader)
+                                  "\\.file$" = ProjectTemplate:::file.reader,
+                                  "\\.mp3$" = ProjectTemplate:::mp3.reader,
+                                  "\\.ppm$" = ProjectTemplate:::ppm.reader)
